==> mktcenter-service-threetree-1.0-20250917.070229-14-sources.jar: com/bizvane/mktcenterservice/models/vo/tree3/respvo/GetDetailActivityCertificationRespVO.java <==
package com.bizvane.mktcenterservice.models.vo.tree3.respvo;

import com.bizvane.mktcenterservice.models.vo.tree3.reqvo.MktActivityCertificationRecordVo;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.util.Date;
import java.util.List;

@Data
public class GetDetailActivityCertificationRespVO {

    private Long mktActivityCertificationId;

    private Long sysCompanyId;

    private Long sysBrandId;

    private String activityName;

    private Date startTime;

    private Date endTime;

    private String province;

    private String city;

    private String district;

    private String detailedAddress;

    private String addressLon;

    private String addressLat;

    private String activityImg;

    private Integer issuanceType;

    private List<GetDetailCertificationTypeRespVO> certificationTypeList;

    private String hostOrgCode;

    private String undertakingUnitName;

    private String activityDetail;

    private Integer state;

    private String onlineOrgCode;

    private String onlineOrgName;

    private String applyQrCode;

    private String signInQrCode;

    @ApiModelProperty(value = "浏览量")
    private Long viewCount;

    @ApiModelProperty(value = "报名人数")
    private Long applyCount;

    @ApiModelProperty(value = "签到人数")
    private Long signInCount;

    @ApiModelProperty(value = "认证人数")
    private Long certificationCount;

    @ApiModelProperty(value = "认证率")
    private String certificationRate;

    @ApiModelProperty(value = "签到状态（1 已签到  0未签到)")
    private Integer signStatus;
    @ApiModelProperty(value = "申请状态 （0未报名 1-已报名）")
    private Integer applyState;
    @ApiModelProperty(value = "报名信息")
    private MktActivityCertificationRecordVo mktActivityCertificationRecordVo;
}

==> mktcenter-service-threetree-1.0-20250918.062252-17-sources.jar: com/bizvane/mktcenterservice/models/vo/tree3/respvo/GetDetailActivityCertificationRespVO.java <==
package com.bizvane.mktcenterservice.models.vo.tree3.respvo;

import com.bizvane.mktcenterservice.models.vo.tree3.reqvo.MktActivityCertificationRecordVo;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.util.Date;
import java.util.List;

@Data
public class GetDetailActivityCertificationRespVO {

    @ApiModelProperty(value = "认证活动ID")
    private Long mktActivityCertificationId;

    private Long sysCompanyId;

    private Long sysBrandId;

    @ApiModelProperty(value = "认证活动名称")
    private String activityName;

    private Date startTime;

    private Date endTime;

    private String province;

    private String city;

    private String district;

    private String detailedAddress;

    private String addressLon;

    private String addressLat;

    @ApiModelProperty(value = "认证活动图片")
    private String activityImg;

    @ApiModelProperty(value = "认证活动说明")
    private Integer issuanceType;

    @ApiModelProperty(value = "认证类型列表")
    private List<GetDetailCertificationTypeRespVO> certificationTypeList;

    private String hostOrgCode;

    private String undertakingUnitName;

    private String activityDetail;

    private Integer state;

    private String onlineOrgCode;

    private String onlineOrgName;

    private String applyQrCode;

    private String signInQrCode;

    @ApiModelProperty(value = "浏览量")
    private Long viewCount;

    @ApiModelProperty(value = "报名人数")
    private Long applyCount;

    @ApiModelProperty(value = "签到人数")
    private Long signInCount;

    @ApiModelProperty(value = "认证人数")
    private Long certificationCount;

    @ApiModelProperty(value = "认证率")
    private String certificationRate;

    @ApiModelProperty(value = "签到状态（1 已签到  0未签到)")
    private Integer signStatus;
    @ApiModelProperty(value = "申请状态 （0未报名 1-已报名）")
    private Integer applyState;
    @ApiModelProperty(value = "报名信息")
    private MktActivityCertificationRecordVo mktActivityCertificationRecordVo;
}
